################################################################################
############################ RESTORATION PLANNING ##############################
################################################################################

# This code was generated by Abigail Wills in 2020 for use in R version 4.0.1 (R Core Team 2020)

### GENERAL INFORMATION

## Title of Project: A practice-led assessment of landscape restoration potential in a biodiversity hotspot

# This code was developed to inform spatially-explicit forest landscape restoration planning,
# first tested in the Udzungwa-Kilombero region in Tanzania. It is based on an approach that prioritizes
# cost-effective ecosystem recovery, accounting for:
# (1) current versus maximum potential biomass (biomass deficit),
# (2) most likely appropriate restoration methods,
# (3) implementation costs, and
# (4) likely biomass(and thus stored carbon) gains.
# Pessimistic, realistic, and optimistic scenarios are incorporated into all four stages and
# above-ground biomass (AGB) gains, implementation costs and cost-effectiveness are estimated
# over two investment timeframes:
# (a) five years, to represent a typical upper limit of donor investment; and
# (b) expected time to full AGB recovery.

# Date of data collection: 2019-2021

## Key contacts:

# Author/Principal Investigator Information
# Name: Abigail Wills
# ORCID: https://orcid.org/0000-0003-3370-156X
# Institution: University of York
# Email: wills.abigail@gmail.com

# Author/Associate or Co-investigator Information
# Name: Andrew Marshall
# Institution: University of the Sunshine Coast
# Email: amarsha1@usc.edu.au

# Author/Alternate Contact Information
# Name: Marion Pfeifer
# Institution: Newcastle University
# Email: Marion.Pfeifer@newcastle.ac.uk

### SHARING/ACCESS INFORMATION

# Licenses/restrictions placed on the data: C0
# Links to publications that cite or use the data: https://doi.org/10.1098/rstb.2021.0070
# Recommended citation for this dataset: As per https://doi.org/10.1098/rstb.2021.0070.
# Links to other publicly accessible locations of the data: R Script (https://bit.ly/3KO5Hgz); Output Maps (https://bit.ly/3QkIrrI)

# Links/relationships to ancillary data sets:
# 0-prep-inputs.r - Code to ensure all input rasters have same extent, resolution, CRS, etc. for processing and to perform conversions where necessary
# 1a-biomass.r - Code to estimate AGB deficit from current and maximum former biomass maps
# 1b-biomass-uncertainty-maps.r - Code to generate envelope uncertainty maps (EUMs), following Platts et al. 2008
# 2-methods.r - Code to assign most likely appropriate restoration methods to each landscape pixel (based on parameters and thresholds in Table 1 in https://doi.org/10.1098/rstb.2021.0070)
# 3-biomass-gain.r - Code to estimate AGB gain after 5 years, and number of years to full-recovery of AGB deficit
# 4a-costs-inputs.r - Code to generate determinents of restoration labour, equipment and transport costs, as detailed in Table S1 and S2 in https://doi.org/10.1098/rstb.2021.0070
  # restCosts_calc.r - Code to estimate 5-year restoration labour and equipment costs per hectare
  # restCosts_calc-full-recovery.r - Code to estimate restoration labour and equipment costs per hectare to full-recovery of maximum above-ground biomass
  # tsportCosts_calc.r - Code to estimate 5-year restoration transport costs per hectare
  # tsportCosts_calc-full-recovery.r - Code to estimate restoration transport costs per hectare to full-recovery of maximum above-ground biomass
# 4b-costs-labour-and-equipment-5y.r - Code to calculate the total labour and equipment costs incurred for each restoration method over a (adjustable) 5 year timeframe
# 4c-costs-transport-5y.r - Code to calculate the total transport costs incurred for each restoration method over a (adjustable) 5 year timeframe
# 4d-costs-labour-and-equipment-full-recovery.r - Code to calculate the total labour and equipment costs incurred for each restoration method to the point of full AGB recovery
# 4e-costs-transport-full-recovery.r - Code to calculate the total transport costs incurred for each restoration method to the point of full AGB recovery
# 4f-costs-totals.r - Code to sum the total labour, equipment, transport and admin costs for each restoration method and overall across the landscape
# 5-cost-effectiveness.r - Code to calculate cost-effectiveness of each landscape pixel based on AGB gains per unit investment, and to identify the top 25% cost-effective pixels for prioritisation

### INSTALL NECESSARY PACKAGES

necessary.packages<-c("raster", "sp", "rgdal")
already.installed<-necessary.packages%in%installed.packages()[, 'Package']    #asks if the necessary packages are already installed in the library?
if (length(necessary.packages[!already.installed])>=1) {    #if any are NOT installed, download them now.
  install.packages(necessary.packages[!already.installed],dep=T)   #are the dependencies really necessary (there are lots!)?
}
sapply(necessary.packages,function(p) {require(p,quietly=T,character.only=T)})

# SET WORKING DIRECTORY:
basename <- "C:/Users/wills/Documents/R/workspaces/UdzKilo_Restoration_Planning"
setwd(basename)

# SETUP INPUT AND OUTPUT STORAGE LOCATIONS IN WORKING DIRECTORY

# INPUTS
inDir <- paste(basename,"inputs",sep="/")
if (file.exists(inDir)){
  cat("\n check directory inputs")
} else {
  dir.create(file.path(inDir))
}

# OUTPUTS
outDir <- paste(basename,"outputs",sep="/")
if (file.exists(outDir)){
  cat("\n check directory outputs")
} else {
  dir.create(file.path(outDir))
}

# Restoration methods
outM<-paste(outDir,"methods",sep="/")
if (file.exists(outM)){
  cat("\n check directory methods")
} else {
  dir.create(file.path(outM))
}

# Methods grouped by approach (passive, ANR, planting)
outA<-paste(outM,"approach",sep="/")
if (file.exists(outA)){
  cat("\n check directory approach")
} else {
  dir.create(file.path(outA))
}

# Remoteness / travel distances to each landscape pixel
outR<-paste(outM,"remoteness",sep="/")
if (file.exists(outR)){
  cat("\n check directory remoteness")
} else {
  dir.create(file.path(outR))
}

# RESTORATION COSTS
outC<-paste(outDir,"costs",sep="/")
if (file.exists(outC)){
  cat("\n check directory costs")
} else {
  dir.create(file.path(outC))
}

# Labour and equipment costs (5 years)
outC5<-paste(outC,"5y",sep="/")
if (file.exists(outC5)){
  cat("\n check directory costs/5y")
} else {
  dir.create(file.path(outC5))
}

# Labour and equipment costs (Full recovery)
outCR<-paste(outC,"restored",sep="/")
if (file.exists(outCR)){
  cat("\n check directory costs/restored")
} else {
  dir.create(file.path(outCR))
}

# Transport costs (inputs, incl. cost surfaces for 1 return trip to each landscape pixel)
outT<-paste(outC,"transport",sep="/")
if (file.exists(outT)){
  cat("\n check directory transport")
} else {
  dir.create(file.path(outT))
}

# Transport costs (5 years)
outC5T<-paste(outC5,"transport",sep="/")
if (file.exists(outC5T)){
  cat("\n check directory 5y/transport")
} else {
  dir.create(file.path(outC5T))
}

# Transport costs (Full recovery)
outCRT<-paste(outCR,"transport",sep="/")
if (file.exists(outCRT)){
  cat("\n check directory restored/transport")
} else {
  dir.create(file.path(outCRT))
}

# SET WORKING DIRECTORY:
setwd(inDir)

########################### PREPARE INPUT RASTERS ##############################                                      <- PREPARE INPUT RASTERS

# Ensure all inputs have same CRS, extent, res, etc.

### CRS correct projectRaster code
#maxbio <- projectRaster(maxbio, currbio)
#writeRaster(maxbio, "agbmax_climate_notaggregated.tif", overwrite = T)

### Easiest way is to resample since there are varying CRSs and extents
temp <- raster("Extent_1.tif") # Template raster used to resample other input rasters
temp
#class      : RasterLayer
#dimensions : 3101, 3445, 10682945  (nrow, ncol, ncell)
#resolution : 100, 100  (x, y)
#extent     : 685971.2, 1030471, 8901502, 9211602  (xmin, xmax, ymin, ymax)
#crs        : +proj=utm +zone=36 +south +datum=WGS84 +units=m +no_defs
#source     : E:/R/workspaces/UdzKilo_Restoration_Planning/inputs/Extent_1.grd
#names      : Extent_1
#values     : 1, 1  (min, max)
sa <- readOGR("Study_Area.shp") # Mask raster for setting pixel values outside Study Region to NA

### BIOMASS RASTERS
currbio <- raster("agbcurr_1ha_rf_full.tif")
maxbio <- raster("agbmax_climate_notaggregated.tif")
currbio <- resample(currbio, temp, method="bilinear")
maxbio <- resample(maxbio, temp, method="bilinear")
writeRaster(currbio, "agbcurr.tif", overwrite = T)
writeRaster(maxbio, "agbmax.tif", overwrite = T)

currbio <- raster("agbcurr_lower_1ha_rf_full.tif")
maxbio <- raster("agbmax_lower_climate_notaggregated.tif")
currbio <- resample(currbio, temp, method="bilinear")
maxbio <- resample(maxbio, temp, method="bilinear")
writeRaster(currbio, "agbcurr_lower.tif", overwrite = T)
writeRaster(maxbio, "agbmax_lower.tif", overwrite = T)

currbio <- raster("agbcurr_upper_1ha_rf_full.tif")
maxbio <- raster("agbmax_upper_climate_notaggregated.tif")
currbio <- resample(currbio, temp, method="bilinear")
maxbio <- resample(maxbio, temp, method="bilinear")
writeRaster(currbio, "agbcurr_upper.tif", overwrite = T)
writeRaster(maxbio, "agbmax_upper.tif", overwrite = T)

### LANDCOVER
r <- raster("LandCoverFinal.tif")
r <- resample(r, temp, method='ngb') # using nearest neighbour 'ngb' method (necessary as categorical dataset; 'bilinear' for continuous)
writeRaster(r, "LandCoverFinal_1ha.tif", overwrite=T)
# Extract and save rasters for individial landcover classes:
lc <- ("LandCoverFinal_1ha.tif")
lcfor <- raster(lc)
lcfor[lc==1] <- 1
lcsav <- raster(lc)
lcsav[lc==2] <- 2
lcfp <- raster(lc)
lcfp[lc==3] <- 3
lcag <- raster(lc)
lcag[lc==4] <- 4
lcoth <- raster(lc)
lcoth[lc==5] <- 5
writeRaster(lcfor, filename = "LandCover_Forest.tif", overwrite=T)
writeRaster(lcsav, filename = "LandCover_Savanna.tif", overwrite=T)
writeRaster(lcfp, filename = "LandCover_Floodplain.tif", overwrite=T)
writeRaster(lcag, filename = "LandCover_AgMosaic.tif", overwrite=T)
writeRaster(lcoth, filename = "LandCover_Other.tif", overwrite=T)

# ELEVATION
r <- raster("dem_srtm_43_4414.tif")
r <- resample(r, temp, method='bilinear')
writeRaster(r, "dem_srtm_1ha.tif", overwrite=T)

