################################################################################
############################ RESTORATION PLANNING ##############################
################################################################################

# This code was generated by Abigail Wills in 2020 for use in R version 4.0.1 (R Core Team 2020)

### GENERAL INFORMATION

## Title of Project: A practice-led assessment of landscape restoration potential in a biodiversity hotspot

# This code was developed to inform spatially-explicit forest landscape restoration planning,
# first tested in the Udzungwa-Kilombero region in Tanzania. It is based on an approach that prioritizes
# cost-effective ecosystem recovery, accounting for:
# (1) current versus maximum potential biomass (biomass deficit),
# (2) most likely appropriate restoration methods,
# (3) implementation costs, and
# (4) likely biomass(and thus stored carbon) gains.
# Pessimistic, realistic, and optimistic scenarios are incorporated into all four stages and
# above-ground biomass (AGB) gains, implementation costs and cost-effectiveness are estimated
# over two investment timeframes:
# (a) five years, to represent a typical upper limit of donor investment; and
# (b) expected time to full AGB recovery.

# Date of data collection: 2019-2021

## Key contacts:

# Author/Principal Investigator Information
# Name: Abigail Wills
# ORCID: https://orcid.org/0000-0003-3370-156X
# Institution: University of York
# Email: wills.abigail@gmail.com

# Author/Associate or Co-investigator Information
# Name: Andrew Marshall
# Institution: University of the Sunshine Coast
# Email: amarsha1@usc.edu.au

# Author/Alternate Contact Information
# Name: Marion Pfeifer
# Institution: Newcastle University
# Email: Marion.Pfeifer@newcastle.ac.uk

### SHARING/ACCESS INFORMATION

# Licenses/restrictions placed on the data: C0
# Links to publications that cite or use the data: https://doi.org/10.1098/rstb.2021.0070
# Recommended citation for this dataset: As per https://doi.org/10.1098/rstb.2021.0070.
# Links to other publicly accessible locations of the data: R Script (https://bit.ly/3KO5Hgz); Output Maps (https://bit.ly/3QkIrrI)

# Links/relationships to ancillary data sets:
# 0-prep-inputs.r - Code to ensure all input rasters have same extent, resolution, CRS, etc. for processing and to perform conversions where necessary
# 1a-biomass.r - Code to estimate AGB deficit from current and maximum former biomass maps
# 1b-biomass-uncertainty-maps.r - Code to generate envelope uncertainty maps (EUMs), following Platts et al. 2008
# 2-methods.r - Code to assign most likely appropriate restoration methods to each landscape pixel (based on parameters and thresholds in Table 1 in https://doi.org/10.1098/rstb.2021.0070)
# 3-biomass-gain.r - Code to estimate AGB gain after 5 years, and number of years to full-recovery of AGB deficit
# 4a-costs-inputs.r - Code to generate determinents of restoration labour, equipment and transport costs, as detailed in Table S1 and S2 in https://doi.org/10.1098/rstb.2021.0070
  # restCosts_calc.r - Code to estimate 5-year restoration labour and equipment costs per hectare
  # restCosts_calc-full-recovery.r - Code to estimate restoration labour and equipment costs per hectare to full-recovery of maximum above-ground biomass
  # tsportCosts_calc.r - Code to estimate 5-year restoration transport costs per hectare
  # tsportCosts_calc-full-recovery.r - Code to estimate restoration transport costs per hectare to full-recovery of maximum above-ground biomass
# 4b-costs-labour-and-equipment-5y.r - Code to calculate the total labour and equipment costs incurred for each restoration method over a (adjustable) 5 year timeframe
# 4c-costs-transport-5y.r - Code to calculate the total transport costs incurred for each restoration method over a (adjustable) 5 year timeframe
# 4d-costs-labour-and-equipment-full-recovery.r - Code to calculate the total labour and equipment costs incurred for each restoration method to the point of full AGB recovery
# 4e-costs-transport-full-recovery.r - Code to calculate the total transport costs incurred for each restoration method to the point of full AGB recovery
# 4f-costs-totals.r - Code to sum the total labour, equipment, transport and admin costs for each restoration method and overall across the landscape
# 5-cost-effectiveness.r - Code to calculate cost-effectiveness of each landscape pixel based on AGB gains per unit investment, and to identify the top 25% cost-effective pixels for prioritisation

################################################################################                                   <- START

### INSTALL NECESSARY PACKAGES

necessary.packages<-c("raster", "sp", "rgdal")
already.installed<-necessary.packages%in%installed.packages()[, 'Package']    #asks if the necessary packages are already installed in the library?
if (length(necessary.packages[!already.installed])>=1) {    #if any are NOT installed, download them now.
  install.packages(necessary.packages[!already.installed],dep=T)   #are the dependencies really necessary (there are lots!)?
}
sapply(necessary.packages,function(p) {require(p,quietly=T,character.only=T)})

# SET WORKING DIRECTORY:
basename <- "C:/Users/wills/Documents/R/workspaces/UdzKilo_Restoration_Planning"
setwd(basename)

# SETUP INPUT AND OUTPUT STORAGE LOCATIONS IN WORKING DIRECTORY

# INPUTS
inDir <- paste(basename,"inputs",sep="/")
if (file.exists(inDir)){
  cat("\n check directory inputs")
} else {
  dir.create(file.path(inDir))
}

# OUTPUTS
outDir <- paste(basename,"outputs",sep="/")
if (file.exists(outDir)){
  cat("\n check directory outputs")
} else {
  dir.create(file.path(outDir))
}

# Restoration methods
outM<-paste(outDir,"methods",sep="/")
if (file.exists(outM)){
  cat("\n check directory methods")
} else {
  dir.create(file.path(outM))
}

# Methods grouped by approach (passive, ANR, planting)
outA<-paste(outM,"approach",sep="/")
if (file.exists(outA)){
  cat("\n check directory approach")
} else {
  dir.create(file.path(outA))
}

# Remoteness / travel distances to each landscape pixel
outR<-paste(outM,"remoteness",sep="/")
if (file.exists(outR)){
  cat("\n check directory remoteness")
} else {
  dir.create(file.path(outR))
}

# RESTORATION COSTS
outC<-paste(outDir,"costs",sep="/")
if (file.exists(outC)){
  cat("\n check directory costs")
} else {
  dir.create(file.path(outC))
}

# Labour and equipment costs (5 years)
outC5<-paste(outC,"5y",sep="/")
if (file.exists(outC5)){
  cat("\n check directory costs/5y")
} else {
  dir.create(file.path(outC5))
}

# Labour and equipment costs (Full recovery)
outCR<-paste(outC,"restored",sep="/")
if (file.exists(outCR)){
  cat("\n check directory costs/restored")
} else {
  dir.create(file.path(outCR))
}

# Transport costs (inputs, incl. cost surfaces for 1 return trip to each landscape pixel)
outT<-paste(outC,"transport",sep="/")
if (file.exists(outT)){
  cat("\n check directory transport")
} else {
  dir.create(file.path(outT))
}

# Transport costs (5 years)
outC5T<-paste(outC5,"transport",sep="/")
if (file.exists(outC5T)){
  cat("\n check directory 5y/transport")
} else {
  dir.create(file.path(outC5T))
}

# Transport costs (Full recovery)
outCRT<-paste(outCR,"transport",sep="/")
if (file.exists(outCRT)){
  cat("\n check directory restored/transport")
} else {
  dir.create(file.path(outCRT))
}

# SET WORKING DIRECTORY:
setwd(inDir)

################################################################################
############################# LANDSCAPE BIOMASS ################################                                   <- LANDSCAPE BIOMASS
################################################################################

################################################################################
############### CALCULATING AGB DEFICIT FROM MAX AND CURRENT AGB ###############                                   <- CALCULATING AGB DEFICIT FROM MAX AND CURRENT AGB

# This section of code computes the difference and percentage difference between
# the current and maximum potential biomass of each landscape pixel. Biomass deficit
# and percentage deficit are also calculated, along with the percentage of maximum
# potential biomass remaining prior to intervention.

# SET WORKING DIRECTORY:
setwd(inDir)

### ENSURE ALL INPUT RASTERS HAVE MATCHING extent, res, crs, origin, etc. ######

### MEAN BIOMASS DEFICIT MAPS (REALISTIC SCENARIO) #############################

### READ IN INPUT RASTERS: SA, CURRBIO & MAXBIO
sa <- readOGR("Study_Area.shp")
currbio <- raster("agbcurr.tif")
maxbio <- raster("agbmax.tif")

### COMPUTE OUTPUT RASTERS: AGBDIFF, PCTDIFF, AGBDEF, PCTDEF, PCTREM
agbdiff <- maxbio - currbio
agbdef <- calc(agbdiff, fun = function(x){x[x < 0] = 0; return(x)})
pctdiff <- overlay(agbdiff, maxbio, fun=function(r1, r2){return(r1/r2)})
pctdef <- overlay(agbdef, maxbio, fun=function(r1, r2){return(r1/r2)})
pctrem <- calc(pctdef, fun=function(x){1-x})

writeRaster(agbdiff, "agbdiff.tif", overwrite = T)
writeRaster(agbdef, "agbdef.tif", overwrite = T)
writeRaster(pctdiff, "agbdiff_pct.tif", overwrite = T)
writeRaster(pctdef, "agbdef_pct.tif", overwrite = T)
writeRaster(pctrem, "agbrem_pct.tif", overwrite = T)

# BIOMASS STACK:
agbs <- stack(currbio, maxbio, agbdiff, pctdiff, agbdef, pctdef, pctrem)
names(agbs) <- c("currbio", "maxbio", "agbdiff", "pctdiff", "agbdef", "pctdef", "pctrem")
agbs
writeRaster(agbs, "biomass_stack.grd", overwrite=T)

### UPPER BIOMASS DEFICIT MAPS (PESSIMISTIC SCENARIO) ##########################
### Largest deficit = lower current - upper max

### READ IN INPUT RASTERS: SA, CURRBIO & MAXBIO
sa <- readOGR("Study_Area.shp")
currbio <- raster("agbcurr_lower.tif")
maxbio <- raster("agbmax_upper.tif")

### COMPUTE OUTPUT RASTERS: AGBDIFF, PCTDIFF, AGBDEF, PCTDEF, PCTREM

agbdiff <- maxbio - currbio
agbdef <- calc(agbdiff, fun = function(x){x[x < 0] = 0; return(x)})
pctdiff <- overlay(agbdiff, maxbio, fun=function(r1, r2){return(r1/r2)})
pctdef <- overlay(agbdef, maxbio, fun=function(r1, r2){return(r1/r2)})
pctrem <- calc(pctdef, fun=function(x){1-x})

writeRaster(agbdiff, "agbdiff_pess.tif", overwrite = T)
writeRaster(agbdef, "agbdef_pess.tif", overwrite = T)
writeRaster(pctdiff, "agbdiff_pct_pess.tif", overwrite = T)
writeRaster(pctdef, "agbdef_pct_pess.tif", overwrite = T)
writeRaster(pctrem, "agbrem_pct_pess.tif", overwrite = T)

# BIOMASS STACK:
agbs <- stack(currbio, maxbio, agbdiff, pctdiff, agbdef, pctdef, pctrem)
names(agbs) <- c("currbio", "maxbio", "agbdiff", "pctdiff", "agbdef", "pctdef", "pctrem")
agbs
writeRaster(agbs, "biomass_stack_pess.grd", overwrite=T)

### LOWER BIOMASS DEFICIT MAPS (OPTIMISTIC SCENARIO) ###########################
### Lowest deficit = upper current - lower max

### READ IN INPUT RASTERS: SA, CURRBIO & MAXBIO
sa <- readOGR("Study_Area.shp")
currbio <- raster("agbcurr_upper.tif")
maxbio <- raster("agbmax_lower.tif")

### COMPUTE OUTPUT RASTERS: AGBDIFF, PCTDIFF, AGBDEF, PCTDEF, PCTREM

agbdiff <- maxbio - currbio
agbdef <- calc(agbdiff, fun = function(x){x[x < 0] = 0; return(x)})
pctdiff <- overlay(agbdiff, maxbio, fun=function(r1, r2){return(r1/r2)})
pctdef <- overlay(agbdef, maxbio, fun=function(r1, r2){return(r1/r2)})
pctrem <- calc(pctdef, fun=function(x){1-x})

writeRaster(agbdiff, "agbdiff_opt.tif", overwrite = T)
writeRaster(agbdef, "agbdef_opt.tif", overwrite = T)
writeRaster(pctdiff, "agbdiff_pct_opt.tif", overwrite = T)
writeRaster(pctdef, "agbdef_pct_opt.tif", overwrite = T)
writeRaster(pctrem, "agbrem_pct_opt.tif", overwrite = T)

# BIOMASS STACK:
agbs <- stack(currbio, maxbio, agbdiff, pctdiff, agbdef, pctdef, pctrem)
names(agbs) <- c("currbio", "maxbio", "agbdiff", "pctdiff", "agbdef", "pctdef", "pctrem")
agbs
writeRaster(agbs, "biomass_stack_opt.grd", overwrite=T)

